package cz.cvut.kbss.reporting.persistence.dao;

import cz.cvut.kbss.reporting.exception.PersistenceException;
import cz.cvut.kbss.reporting.model.OccurrenceReport;
import cz.cvut.kbss.reporting.model.Tag;
import org.springframework.stereotype.Repository;

import java.util.List;
import java.util.stream.Collectors;

@Repository
public class OccurrenceReportDao extends BaseDao<OccurrenceReport> {

    private final TagDao tagDao;

    public OccurrenceReportDao(TagDao tagDao) {
        super(OccurrenceReport.class);
        this.tagDao = tagDao;
    }

    @Override
    public List<OccurrenceReport> findAll() {
        return em.createNamedQuery(OccurrenceReport.FIND_ALL, OccurrenceReport.class).getResultList();
    }

    @Override
    public void persist(OccurrenceReport entity) {
        try {
            if (entity.getTags() != null) {
                tagDao.persist(entity.getTags().stream().filter(t -> t.getId() == null).collect(Collectors.toList()));
            }
            em.persist(entity);
        } catch (RuntimeException e) {
            throw new PersistenceException(e);
        }
    }

    /**
     * Finds {@link OccurrenceReport} instances by specific tag.
     *
     * @param tag tag to filter by
     * @return List of instances, empty list if none matches
     */
    public List<OccurrenceReport> findAll(Tag tag) {
        return em.createNamedQuery(OccurrenceReport.FIND_ALL_BY_TAG, OccurrenceReport.class)
                 .setParameter("tag", tag)
                 .getResultList();

    }
}
