import React from "react";
import PropTypes from "prop-types";
import {Button, Panel} from "react-bootstrap";

import I18nWrapper from "../../i18n/I18nWrapper";
import injectIntl from "../../utils/injectIntl";
import Mask from "../Mask";
import ReportsTable from "./ReportsTable";

class Reports extends React.Component {
    constructor(props) {
        super(props);
        this.i18n = props.i18n;
    }

    render() {
        if (this.props.reports === null) {
            return <Mask text={this.i18n('reports.loading-mask')}/>;
        }
        return <Panel header={<h3>{this.i18n('reports.panel-title')}</h3>} bsStyle='primary'>
            <ReportsTable reports={this.props.reports} actions={this.props.actions} types={this.props.types}/>
            {this._renderCreateReport()}
        </Panel>;
    }

    _renderCreateReport() {
        if (this.props.reports.length !== 0) {
            return <div>
                <Button bsStyle='primary'
                        onClick={this.props.actions.createReport}>{this.i18n('reports.create-report')}</Button>
            </div>;
        }
        return <div className='no-reports-notice italics'>
            {this.i18n('reports.no-reports')}
            <a href='javascript:void(0);' onClick={this.props.actions.createReport}
               title={this.i18n('reports.no-reports.link-tooltip')}>
                {this.i18n('reports.no-reports.link')}
            </a>
        </div>;
    }
}

Reports.propTypes = {
    reports: PropTypes.array,
    types: PropTypes.array,
    actions: PropTypes.object.isRequired
};

export default injectIntl(I18nWrapper(Reports));
